==> ddd_2.2.3.orig.tar.gz: ddd-2.2.3/ddd/fortranize.h <==
// $Id: fortranize.h,v 1.1 1998/01/12 17:05:52 zeller Exp $ -*- C++ -*-
// Convert identifiers to FORTRAN format

// Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of the DDD Library.
// 
// The DDD Library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// The DDD Library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Library General Public License for more details.
// 
// You should have received a copy of the GNU Library General Public
// License along with the DDD Library -- see the file COPYING.LIB.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_fortranize_h
#define _DDD_fortranize_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Return ID in `fortranized' form -- that is, in lower case and with
// `_' appended.  If GLOBALS_FIRST is set, try global symbols first.
extern string fortranize(const string& id, bool globals_first = false);

#endif // _DDD_fortranize_h
// DON'T ADD ANYTHING BEHIND THIS #endif

==> ddd-3.1.tar.gz: ddd-3.1/ddd/fortranize.h <==
// $Id: fortranize.h,v 1.3 1998/05/06 16:02:43 zeller Exp $ -*- C++ -*-
// Convert identifiers to FORTRAN format

// Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_fortranize_h
#define _DDD_fortranize_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Return ID in `fortranized' form -- that is, in lower/upper case and
// with `_' appended.  If GLOBALS_FIRST is set, try global symbols first.
extern string fortranize(const string& id, bool globals_first = false);

#endif // _DDD_fortranize_h
// DON'T ADD ANYTHING BEHIND THIS #endif
